load_data: Load the raw NOAA data

Description Usage Arguments Value Examples

View source: R/clean_data.R

Description

This will load the raw tab delimited data previously downloaded from the NOAA website which is currently sitting in the data folder.

Usage

1
load_data(path = file.path("data_raw", "signif.txt"))

Arguments

path

A character string file path to your downloaded data source. Default is "data/signif.txt"

Value

Returns a dataframe result after calling readr's read_delim

Examples

1
2
3
4
5
6
## Not run: 
  df <- load_data()
  print(class(df))
  head(df)

## End(Not run)

Alexandershemetev/alexandrshemetev documentation built on Oct. 15, 2020, 12:02 a.m.